# ============ List of structure to annotate ============

LIST_STRUCTURES = [
    "LABEL",
]

DICT_SUB_STRUCTURES = {
    "LABEL":[
        'Structure of interest',
        'Other']
}